@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Synthesizer settings librarian
 
-our $VERSION = '0.0051';
+our $VERSION = '0.0052';
 
 use Moo;
 use strictures 2;
@@ -341,7 +341,6 @@ sub graphviz {
   my ($self, %options) = @_;
 
   die 'Model not given' unless $options{model_name};
-  die 'Patch not given' unless $options{patch_name};
 
   $options{render}    ||= 0;
   $options{path}      ||= '.';
@@ -356,9 +355,11 @@ sub graphviz {
   );
   my (%edges, %sets, %labels);
 
+  my $patch_name = '';
   # collect settings by group
   for my $set (@{ $options{settings} }) {
     my $from = $set->{group};
+    $patch_name = $set->{name};
     push @{ $sets{$from} }, $set;
   }
 
@@ -374,9 +375,9 @@ sub graphviz {
   }
 
   # add patch edges
-  for my $s (@{ $options{settings} }) {
-    next if $s->{control} ne 'patch';
-    my ($from, $to, $param, $param_to) = @$s{qw(group group_to parameter param_to)};
+  for my $set (@{ $options{settings} }) {
+    next if $set->{control} ne 'patch';
+    my ($from, $to, $param, $param_to) = @$set{qw(group group_to parameter param_to)};
     my $key = "$from $param to $to $param_to";
     my $label = "$param to $param_to";
     $from = $labels{$from};
@@ -391,7 +392,7 @@ sub graphviz {
   if ($options{render}) {
     # save the file
     (my $model = $options{model_name}) =~ s/\W/_/g;
-    (my $patch = $options{patch_name}) =~ s/\W/_/g;
+    (my $patch = $patch_name) =~ s/\W/_/g;
     my $filename = "$options{path}/$model-$patch.$options{extension}";
     $g->run(format => $options{extension}, output_file => $filename);
   }
@@ -413,14 +414,14 @@ Synth::Config - Synthesizer settings librarian
 
 =head1 VERSION
 
-version 0.0051
+version 0.0052
 
 =head1 SYNOPSIS
 
   use Synth::Config ();
 
   my $model = 'Modular';
-  my $synth = Synth::Config->new(model => $model);
+  my $synth = Synth::Config->new(model => $model, verbose => 1);
 
   # populate the database with patch settings from a YAML file or string
   my $patches = $synth->import_yaml(
@@ -434,7 +435,7 @@ version 0.0051
   my $id2 = $synth->make_setting(name => $patch, group => 'sequencer', etc => '...');
 
   my $setting = $synth->recall_setting(id => $id1);
-  # { id => 1, group => 'filter' }
+  # { id => 1, group => 'filter', etc => '...' }
 
   # update the group key
   $synth->make_setting(id => $id1, group => 'envelope');
@@ -448,13 +449,11 @@ version 0.0051
   my $g = $synth->graphviz(
     settings   => $settings,
     model_name => $model,
-    patch_name => $patch,
   );
   # or
   $synth->graphviz(
     settings   => $settings,
     model_name => $model,
-    patch_name => $patch,
     render     => 1,
   );
 
